/** @jsxImportSource theme-ui */
import { HTMLAttributeAnchorTarget, ReactNode } from 'react';
import { LinkProps } from 'theme-ui';
/**
 * The props for the anchor component.
 * @extends LinkProps
 */
export interface AnchorProps extends LinkProps {
    /**
     * A flag indicating whether the href is an external link.
     * @default false
     */
    external?: boolean;
    /**
     * The target to open the link in. The default value only applies when the `external` flag is `true`.
     */
    target?: HTMLAttributeAnchorTarget;
    /**
     * The relationship between the linked resource and the current document.
     * The default value only applies when the `external` flag is `true`.
     */
    rel?: string;
    /**
     * The react component to display inside the anchor.
     */
    children: ReactNode;
    /** Should the anchor render without css styles */
    noDecoration?: boolean;
}
/**
 * A styled HTML `<a>` element which creates a hyperlink to the provided URL.
 * Content passed in via the `children` prop should indicate the link's destination.
 * See https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a for more details
 * about the HTML `<a>` element.
 */
export declare const Anchor: ({ external, ...rest }: AnchorProps) => import("theme-ui/jsx-runtime").JSX.Element;
//# sourceMappingURL=anchor.d.ts.map