"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const jsx_runtime_1 = require("theme-ui/jsx-runtime");
/** @jsxImportSource theme-ui */
const react_1 = __importDefault(require("react"));
const theme_ui_1 = require("theme-ui");
const spinner_1 = require("../spinner");
const icon_1 = require("../icon");
const text_1 = require("../text");
const useIsDarkMode_1 = require("../hooks/useIsDarkMode");
const button_styles_1 = require("./button.styles");
const button_fx_1 = require("./button.fx");
/**
 * A pre-styled button with multiple sizes and variants. Supports loading, disabled, and active states.
 */
const Button = (_a) => {
    var { children, icon, width, minWidth, maxWidth, fullWidth, variant = 'primary', size = 'sm', hideContentWhileLoading = false, loading = false, disabled = false, active = false } = _a, rest = __rest(_a, ["children", "icon", "width", "minWidth", "maxWidth", "fullWidth", "variant", "size", "hideContentWhileLoading", "loading", "disabled", "active"]);
    const isDarkMode = (0, useIsDarkMode_1.useIsDarkMode)();
    const shouldBeDisabled = disabled || loading;
    const shouldRenderChildren = !!children && (!loading || !hideContentWhileLoading);
    const shouldRenderIcon = !loading && icon;
    const buttonSx = react_1.default.useMemo(() => {
        const buttonCssParams = {
            variant,
            size,
            darkMode: isDarkMode,
            active,
            width,
            minWidth,
            maxWidth,
            fullWidth,
        };
        return (0, button_styles_1.buttonCss)(buttonCssParams);
    }, [variant, size, isDarkMode, active, width, minWidth, maxWidth, fullWidth]);
    const buttonAddonSx = react_1.default.useMemo(() => {
        const buttonAddonCssParams = {
            variant,
            size,
            hasChildren: shouldRenderChildren,
        };
        return (0, button_styles_1.buttonAddonCss)(buttonAddonCssParams);
    }, [variant, size, shouldRenderChildren]);
    const spinnerSize = size === 'sm' ? 'sm' : 'md';
    return ((0, jsx_runtime_1.jsxs)(theme_ui_1.Button, Object.assign({ sx: buttonSx, disabled: shouldBeDisabled }, rest, { children: [loading && ((0, jsx_runtime_1.jsx)(theme_ui_1.Flex, Object.assign({ sx: buttonAddonSx }, { children: (0, jsx_runtime_1.jsx)(spinner_1.Spinner, { size: spinnerSize }) }))), shouldRenderIcon && ((0, jsx_runtime_1.jsx)(theme_ui_1.Flex, Object.assign({ sx: buttonAddonSx }, { children: (0, jsx_runtime_1.jsx)(icon_1.Icon, Object.assign({ size: "sm" }, icon)) }))), shouldRenderChildren && ((0, jsx_runtime_1.jsx)(text_1.Text, Object.assign({ variant: (0, button_fx_1.getTextVariant)(size), inline: true }, { children: children })))] })));
};
exports.Button = Button;
