import { ButtonVariant, Size } from '@waystone/core';
declare type getBackgroundColorProps = {
    variant?: ButtonVariant;
    darkMode?: boolean;
};
export declare const getBackgroundColor: ({ variant, }: getBackgroundColorProps) => string;
/**
 * If the variant is ghost, return muted, if it's link, return transparent, otherwise return the
 * variant with a -100 suffix.
 * @param {ButtonVariant} variant - ButtonVariant
 * @returns A function that takes a variant and returns a color.
 */
export declare const getHoverBackgroundColor: ({ variant, darkMode, }: getBackgroundColorProps) => string;
/**
 * If the variant is ghost, return muted, if it's link, return transparent, otherwise return the
 * variant with a 600 appended to it.
 * @param {ButtonVariant} variant - ButtonVariant
 * @returns A function that takes a variant and returns a color.
 */
export declare const getActiveBackgroundColor: ({ variant, darkMode, }: getBackgroundColorProps) => string;
/**
 * It returns a string based on the variant passed in
 * @param {ButtonVariant} variant - The variant of the button.
 * @returns A string
 */
export declare const getColor: (variant?: ButtonVariant) => "b-600" | "text";
/**
 * Gets the active color for a link button based on the dark mode
 * @param darkMode - Is the app using dark mode?
 * @returns
 */
export declare const getLinkVariantActiveColor: (darkMode: boolean) => "h-400" | "h-700";
/**
 * Gets the hover color for a link button based on the dark mode
 * @param darkMode - Is the app using dark mode?
 * @returns
 */
export declare const getLinkVariantHoverColor: (darkMode: boolean) => "h-300" | "h-600";
/**
 * `ComputedBoxShadowStyles` is an object with three properties: `normal`, `hover`, and `active`. Each
 * of those properties is a string.
 * @property {string} normal - The box-shadow style for the normal state.
 * @property {string} hover - The box-shadow style when the user hovers over the button.
 * @property {string} active - The box-shadow style when the button is active.
 */
declare type ComputedBoxShadowStyles = {
    normalBoxShadow: string;
    hoverBoxShadow: string;
    activeBoxShadow: string;
};
declare type getBoxShadowProps = {
    variant?: ButtonVariant;
    darkMode?: boolean;
};
export declare const getBoxShadow: ({ variant, darkMode, }: getBoxShadowProps) => ComputedBoxShadowStyles;
/**
 * `ComputedPaddingStyles` is an object with two properties, `paddingX` and `paddingY`, which are both
 * strings or numbers.
 * @property {string | number} paddingX - The padding on the left and right sides of the component.
 * @property {string | number} paddingY - The padding on the top and bottom of the component.
 */
declare type ComputedPaddingStyles = {
    paddingX: string | number;
    paddingY: string | number;
};
declare type getPaddingProps = {
    variant?: ButtonVariant;
    size?: Size;
};
export declare const getPadding: ({ variant, size, }: getPaddingProps) => ComputedPaddingStyles;
export {};
//# sourceMappingURL=button.styles.fx.d.ts.map