"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPadding = exports.getBoxShadow = exports.getLinkVariantHoverColor = exports.getLinkVariantActiveColor = exports.getColor = exports.getActiveBackgroundColor = exports.getHoverBackgroundColor = exports.getBackgroundColor = void 0;
const core_1 = require("@waystone/core");
const getBackgroundColor = ({ variant = 'primary', }) => {
    switch (variant) {
        case 'ghost':
            return 'ghost';
        case 'link':
            return 'transparent';
        case 'primary':
        case 'secondary':
        case 'accent':
        case 'highlight':
        default:
            return `${variant[0]}-400`;
    }
};
exports.getBackgroundColor = getBackgroundColor;
/**
 * If the variant is ghost, return muted, if it's link, return transparent, otherwise return the
 * variant with a -100 suffix.
 * @param {ButtonVariant} variant - ButtonVariant
 * @returns A function that takes a variant and returns a color.
 */
const getHoverBackgroundColor = ({ variant = 'primary', darkMode, }) => {
    switch (variant) {
        case 'ghost':
            return darkMode ? 'b-500' : 'b-000';
        case 'link':
            return 'transparent';
        case 'primary':
        case 'secondary':
        case 'accent':
        case 'highlight':
        default:
            return `${variant[0]}-300`;
    }
};
exports.getHoverBackgroundColor = getHoverBackgroundColor;
/**
 * If the variant is ghost, return muted, if it's link, return transparent, otherwise return the
 * variant with a 600 appended to it.
 * @param {ButtonVariant} variant - ButtonVariant
 * @returns A function that takes a variant and returns a color.
 */
const getActiveBackgroundColor = ({ variant = 'primary', darkMode, }) => {
    switch (variant) {
        case 'ghost':
            return darkMode ? 'b-500' : 'white';
        case 'link':
            return 'transparent';
        case 'primary':
        case 'secondary':
        case 'accent':
        case 'highlight':
        default:
            return `${variant[0]}-200`;
    }
};
exports.getActiveBackgroundColor = getActiveBackgroundColor;
/**
 * It returns a string based on the variant passed in
 * @param {ButtonVariant} variant - The variant of the button.
 * @returns A string
 */
const getColor = (variant) => {
    switch (variant) {
        case 'primary':
        case 'secondary':
        case 'accent':
        case 'highlight':
            return 'b-600';
        default:
            return 'text';
    }
};
exports.getColor = getColor;
/**
 * Gets the active color for a link button based on the dark mode
 * @param darkMode - Is the app using dark mode?
 * @returns
 */
const getLinkVariantActiveColor = (darkMode) => darkMode ? 'h-400' : 'h-700';
exports.getLinkVariantActiveColor = getLinkVariantActiveColor;
/**
 * Gets the hover color for a link button based on the dark mode
 * @param darkMode - Is the app using dark mode?
 * @returns
 */
const getLinkVariantHoverColor = (darkMode) => darkMode ? 'h-300' : 'h-600';
exports.getLinkVariantHoverColor = getLinkVariantHoverColor;
const getBoxShadow = ({ variant = 'primary', darkMode, }) => {
    if (['ghost', 'link'].includes(variant)) {
        return {
            normalBoxShadow: 'none',
            hoverBoxShadow: 'none',
            activeBoxShadow: 'none',
        };
    }
    return {
        normalBoxShadow: (0, core_1.addDarkModeSuffix)('sm', darkMode),
        hoverBoxShadow: (0, core_1.addDarkModeSuffix)('md', darkMode),
        activeBoxShadow: (0, core_1.addDarkModeSuffix)('sm', darkMode),
    };
};
exports.getBoxShadow = getBoxShadow;
const getPadding = ({ variant = 'primary', size, }) => {
    if (variant === 'link')
        return { paddingX: 0, paddingY: 0 };
    switch (size) {
        case 'sm': {
            return {
                paddingX: 'sm',
                paddingY: 'xs',
            };
        }
        case 'lg': {
            return {
                paddingX: 'xl',
                paddingY: 'sm',
            };
        }
        default:
            return {
                paddingX: 'lg',
                paddingY: 'sm',
            };
    }
};
exports.getPadding = getPadding;
