"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buttonAddonCss = exports.buttonCss = void 0;
const color_1 = require("@theme-ui/color");
const button_styles_fx_1 = require("./button.styles.fx");
const buttonCss = ({ variant, size, darkMode, width, minWidth, maxWidth, fullWidth, active, }) => {
    const { normalBoxShadow, hoverBoxShadow, activeBoxShadow } = (0, button_styles_fx_1.getBoxShadow)({
        variant,
        darkMode,
    });
    const { paddingX, paddingY } = (0, button_styles_fx_1.getPadding)({ variant, size });
    const color = (0, button_styles_fx_1.getColor)(variant);
    const outlineColor = darkMode ? 'b-600' : 'info-000';
    const isLink = variant === 'link';
    const hoverCss = {
        color: isLink ? (0, button_styles_fx_1.getLinkVariantHoverColor)(darkMode) : color,
        boxShadow: hoverBoxShadow,
        backgroundColor: (0, button_styles_fx_1.getHoverBackgroundColor)({ variant, darkMode }),
    };
    const focusCss = {
        color: isLink ? (0, button_styles_fx_1.getLinkVariantActiveColor)(darkMode) : color,
        boxShadow: activeBoxShadow,
        backgroundColor: (0, button_styles_fx_1.getActiveBackgroundColor)({ variant, darkMode }),
        outlineColor: (0, color_1.alpha)(outlineColor, 1),
        outlineWidth: 'sm',
        outlineStyle: 'solid',
    };
    const activeCss = {
        color: isLink ? (0, button_styles_fx_1.getLinkVariantActiveColor)(darkMode) : color,
        boxShadow: activeBoxShadow,
        backgroundColor: (0, button_styles_fx_1.getActiveBackgroundColor)({ variant, darkMode }),
        outlineColor: (0, color_1.alpha)(outlineColor, 0),
        outlineWidth: 'sm',
        outlineStyle: 'solid',
    };
    const baseCss = {
        display: 'flex',
        flexWrap: 'nowrap',
        alignItems: 'center',
        justifyContent: 'center',
        color,
        backgroundColor: (0, button_styles_fx_1.getBackgroundColor)({ variant, darkMode }),
        paddingX,
        paddingY,
        width: fullWidth ? '100%' : width,
        maxWidth: !fullWidth && maxWidth,
        minWidth: !fullWidth && minWidth,
        boxShadow: normalBoxShadow,
        margin: 0,
        cursor: 'pointer',
        transition: 'all 200ms ease',
        outlineColor: (0, color_1.alpha)(outlineColor, 0),
        outlineWidth: 'sm',
        outlineStyle: 'solid',
        ':enabled:hover': Object.assign({}, hoverCss),
        ':not(active):focus': Object.assign({}, focusCss),
        ':enabled:active': Object.assign({}, activeCss),
        ':disabled': {
            color: 'b-400',
            backgroundColor: !isLink && 'muted',
            cursor: 'not-allowed',
        },
    };
    if (active) {
        return Object.assign(Object.assign({}, baseCss), activeCss);
    }
    return baseCss;
};
exports.buttonCss = buttonCss;
const buttonAddonCss = ({ hasChildren, variant, size, }) => ({
    marginRight: hasChildren && 'sm',
    marginY: (0, button_styles_fx_1.getPadding)({ variant, size }),
});
exports.buttonAddonCss = buttonAddonCss;
