import React from 'react';
import { CanBeFullWidth, CanDisable, CanLoad, HasHeight, HasWidth } from '../common';
/**
 * The props that can be passed to the CardButton component.
 */
export interface CardButtonProps extends HasWidth, HasHeight, CanDisable, CanLoad, CanBeFullWidth {
    /** A custom onClick handler that will be executed when the button is clicked. */
    onClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /** Should the card button render without any dropshadow. */
    noShadow?: boolean;
    /** The content to render inside the card button. */
    children: React.ReactNode;
}
/**
 * A button that shares the same styling as a card.
 * @param props - The props that can be passed to the CardButton component.
 * @param props.children - The content to render inside the card button.
 * @param props.onClick - A custom onClick handler that will be executed when the button is clicked.
 * @param props.noShadow - Should the card button render without any dropshadow.
 * @param props.width - The width of the card button.
 * @param props.minWidth - The minimum width of the card button.
 * @param props.maxWidth - The maximum width of the card button.
 * @param props.height - The height of the card button.
 * @param props.minHeight - The minimum height of the card button.
 * @param props.maxHeight - The maximum height of the card button.
 * @param props.disabled - Should the card button be disabled.
 * @param props.loading - Should the card button be loading.
 * @param props.fullWidth - Should the card button be full width.
 * @returns The rendered card button.
 */
export declare const CardButton: ({ children, fullWidth, width, minWidth, maxWidth, noShadow, disabled, loading, onClick, ...rest }: CardButtonProps) => import("theme-ui/jsx-runtime").JSX.Element;
//# sourceMappingURL=cardButton.d.ts.map