"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CardButton = void 0;
const jsx_runtime_1 = require("theme-ui/jsx-runtime");
/** @jsxImportSource theme-ui */
const color_1 = require("@theme-ui/color");
const useIsDarkMode_1 = require("../hooks/useIsDarkMode");
const spinner_1 = require("../spinner");
/**
 * A button that shares the same styling as a card.
 * @param props - The props that can be passed to the CardButton component.
 * @param props.children - The content to render inside the card button.
 * @param props.onClick - A custom onClick handler that will be executed when the button is clicked.
 * @param props.noShadow - Should the card button render without any dropshadow.
 * @param props.width - The width of the card button.
 * @param props.minWidth - The minimum width of the card button.
 * @param props.maxWidth - The maximum width of the card button.
 * @param props.height - The height of the card button.
 * @param props.minHeight - The minimum height of the card button.
 * @param props.maxHeight - The maximum height of the card button.
 * @param props.disabled - Should the card button be disabled.
 * @param props.loading - Should the card button be loading.
 * @param props.fullWidth - Should the card button be full width.
 * @returns The rendered card button.
 */
const CardButton = (_a) => {
    var { children, fullWidth, width, minWidth, maxWidth, noShadow, disabled, loading, onClick } = _a, rest = __rest(_a, ["children", "fullWidth", "width", "minWidth", "maxWidth", "noShadow", "disabled", "loading", "onClick"]);
    const darkMode = (0, useIsDarkMode_1.useIsDarkMode)();
    const cardCss = Object.assign(Object.assign({ position: 'relative', paddingX: 'md', paddingY: 'md', border: 'none', borderRadius: 'md', color: 'text', width: fullWidth ? '100%' : width || 'auto', minWidth: !fullWidth && minWidth, maxWidth: !fullWidth && maxWidth, backgroundColor: darkMode ? 'b-600' : 'b-000', boxShadow: !noShadow && 'md', cursor: 'pointer', outlineColor: (0, color_1.alpha)('info-000', 0), outlineWidth: 'sm', outlineStyle: 'solid', overflow: 'hidden', textAlign: 'left', transition: 'all 200ms' }, rest), { ':enabled:hover': {
            backgroundColor: darkMode ? 'b-500' : 'b-100',
        }, ':enabled:focus': {
            outlineColor: (0, color_1.alpha)('info-000', 0.75),
            outlineWidth: 'sm',
            outlineStyle: 'solid',
        }, ':enabled:active': {
            backgroundColor: darkMode ? 'b-400' : 'b-200',
        }, ':disabled': {
            color: 'b-400',
            backgroundColor: 'muted',
            cursor: 'not-allowed',
        } });
    return ((0, jsx_runtime_1.jsxs)("button", Object.assign({ sx: cardCss, onClick: onClick, type: "button", disabled: disabled || loading }, { children: [loading && (0, jsx_runtime_1.jsx)(spinner_1.Spinner, { overlay: true }), children] })));
};
exports.CardButton = CardButton;
