import { ThemeSize } from '@waystone/core';
import { StylePropertyValue, ThemeUIStyleObject } from 'theme-ui';
import { Property } from 'csstype';
import { CanBeFullWidth, HasHeight, HasWidth } from '../common/interfaces';
/** THe props for styling the card container */
interface CardContainerCssProps extends HasWidth, HasHeight, CanBeFullWidth {
    /** Should the card not have a shadow */
    noShadow?: boolean;
    /** Is the app in dark mode. */
    darkMode?: boolean;
}
export declare const cardContainerCss: ({ fullWidth, width, minWidth, maxWidth, noShadow, darkMode, ...rest }: CardContainerCssProps) => ThemeUIStyleObject;
/**
 * The props for styling the card's cover image.
 * The cover image is considered a background-image.
 */
export interface CoverImageCssOptions {
    /** The url of the background image. */
    url: string;
    /** The cover image size. */
    size?: 'contain' | 'cover' | 'auto' | string;
    /** The covert image repeat setting. */
    repeat?: 'repeat' | 'no-repeat' | 'repeat-x' | 'repeat-y';
    /** The cover image position. */
    position?: 'top' | 'bottom' | 'left' | 'right' | 'center';
    /** The height of the cover image. */
    height?: ThemeSize | ThemeSize[] | StylePropertyValue<Property.Height<string | number>>;
    /** The fallback color if the cover image cannot be rendered. */
    fallbackColor?: string;
}
export declare const coverImageCss: ({ url, size, repeat, position, height, fallbackColor, }: CoverImageCssOptions) => ThemeUIStyleObject;
export declare const cardContentCss: (noPadding?: boolean) => ThemeUIStyleObject;
export {};
//# sourceMappingURL=card.styles.d.ts.map