export interface CodeBlockProps {
    /**
     * The code language to use for syntax highlighting.
     * @default 'text'
     * @see https://github.com/react-syntax-highlighter/react-syntax-highlighter/blob/HEAD/AVAILABLE_LANGUAGES_HLJS.MD
     */
    language?: string;
    /**
     * A flag indicating whether the code block should wrap long lines.
     * @default false
     */
    wordWrap?: boolean;
    /**
     * A flag indicating whether the code block should hide line numbers.
     * @default false
     */
    hideLineNumbers?: boolean;
    /**
     * The text to render as code.
     */
    children: string;
    /** An optional caption to describe the code block. */
    caption?: string;
}
/**
 * Renders a code block that supports syntax highlighting using HLJS.
 * Refer to https://github.com/react-syntax-highlighter/react-syntax-highlighter/blob/HEAD/AVAILABLE_LANGUAGES_HLJS.MD
 * for the list of available languages.
 * @param props.language - the language of the code inside the codeblock. Used for syntax highlighting.
 * @param props.wordWrap - a flag indicating whether the code block should wrap long lines.
 * @param props.hideLineNumbers - a flag indicating whether the code block should hide line numbers.
 * @param props.caption - an optional caption to describe the code block.
 * @param props.children - the code to render.
 * @returns a code block component.
 */
export declare const CodeBlock: ({ language, wordWrap, hideLineNumbers, caption, children, }: CodeBlockProps) => import("theme-ui/jsx-runtime").JSX.Element;
//# sourceMappingURL=codeBlock.d.ts.map