"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeBlock = void 0;
const jsx_runtime_1 = require("theme-ui/jsx-runtime");
/** @jsxImportSource theme-ui */
const react_1 = __importDefault(require("react"));
const react_syntax_highlighter_1 = __importDefault(require("react-syntax-highlighter"));
const hljs_1 = require("react-syntax-highlighter/dist/cjs/styles/hljs");
const icon_1 = require("../icon/icon");
const codeBlock_fx_1 = require("./codeBlock.fx");
const codeBlock_styles_1 = require("./codeBlock.styles");
/**
 * Renders a code block that supports syntax highlighting using HLJS.
 * Refer to https://github.com/react-syntax-highlighter/react-syntax-highlighter/blob/HEAD/AVAILABLE_LANGUAGES_HLJS.MD
 * for the list of available languages.
 * @param props.language - the language of the code inside the codeblock. Used for syntax highlighting.
 * @param props.wordWrap - a flag indicating whether the code block should wrap long lines.
 * @param props.hideLineNumbers - a flag indicating whether the code block should hide line numbers.
 * @param props.caption - an optional caption to describe the code block.
 * @param props.children - the code to render.
 * @returns a code block component.
 */
const CodeBlock = ({ language = 'text', wordWrap = false, hideLineNumbers = false, caption, children, }) => {
    const [iconName, setIconName] = react_1.default.useState('content_copy');
    const handleCopy = () => {
        (0, codeBlock_fx_1.copy)(children);
        setIconName('done');
    };
    const handleBlur = () => {
        setIconName('content_copy');
    };
    return ((0, jsx_runtime_1.jsxs)("div", Object.assign({ sx: codeBlock_styles_1.codeBlockContainerCss }, { children: [(0, jsx_runtime_1.jsx)("div", Object.assign({ sx: codeBlock_styles_1.codeBlockLanguageCss }, { children: language })), (0, jsx_runtime_1.jsx)("button", Object.assign({ sx: codeBlock_styles_1.codeBlockCopyButtonCss, type: "button", onClick: handleCopy, onBlur: handleBlur }, { children: (0, jsx_runtime_1.jsx)(icon_1.Icon, { name: iconName }) })), (0, jsx_runtime_1.jsx)(react_syntax_highlighter_1.default, Object.assign({ wrapLongLines: wordWrap, showLineNumbers: !hideLineNumbers, language: language, style: hljs_1.tomorrowNight, customStyle: {
                    backgroundColor: 'inherit',
                    fontFamily: 'inherit',
                    fontWeight: 'inherit',
                    lineHeight: 'inherit',
                    paddingTop: '2rem',
                    paddingBottom: caption ? '2.25rem' : '1.5rem',
                } }, { children: children })), caption && (0, jsx_runtime_1.jsx)("div", Object.assign({ sx: codeBlock_styles_1.codeBlockCaptionCss }, { children: caption }))] })));
};
exports.CodeBlock = CodeBlock;
