/** @jsxImportSource theme-ui */
import React from 'react';
import type { LiteralUnion } from 'type-fest';
import { HasColor, HasSize, HasVariant } from '../common/interfaces';
import { IconStyleProps, IconVariant, MaterialIconName } from './icon.types';
/**
 * The options that can be set when rendering the icon.
 * @extends IconStyleProps
 * @extends HasVariant
 */
export interface IconOptions extends IconStyleProps, HasVariant<IconVariant> {
}
/** Props for the icon component. */
export interface IconProps extends Omit<React.HTMLAttributes<HTMLElement>, 'children' | 'color'>, HasVariant<IconVariant>, HasSize, HasColor {
    /** The name of the material icon to render. */
    name: LiteralUnion<MaterialIconName, string>;
}
/**
 * Renders an icon component.
 * This component library relies on the material-icons font for rendering icons.
 * You can view the list of available icons by going to https://fonts.google.com/icons
 */
export declare const Icon: ({ className, name, variant, size, color, ...rest }: IconProps) => import("theme-ui/jsx-runtime").JSX.Element;
//# sourceMappingURL=icon.d.ts.map