import React, { PropsWithChildren } from 'react';
/** The value provided by the {@link SpinnerContext} */
export interface SpinnerContextValue {
    /** A function that shows the spinner. */
    show?: () => void;
    /** A function that hides the spinner. */
    hide?: () => void;
}
export interface SpinnerProviderProps {
    initialVisible?: boolean;
}
/** The context for the {@link SpinnerContextValue} */
export declare const SpinnerContext: React.Context<SpinnerContextValue>;
/**
 * A component that provides the {@link SpinnerContextValue} to its children
 * and renders the spinner component onto the DOM.
 * @param props.children - the children of the component
 * @returns the spinner context provider
 */
export declare const SpinnerProvider: React.FC<PropsWithChildren<SpinnerProviderProps>>;
/**
 * A hook that provides access to the {@link SpinnerContextValue} when
 * used within a {@link SpinnerProvider}.
 * @returns the spinner context value
 */
export declare const useSpinnerContext: () => SpinnerContextValue;
//# sourceMappingURL=spinner.context.d.ts.map