"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSpinnerContext = exports.SpinnerProvider = exports.SpinnerContext = void 0;
const react_1 = __importDefault(require("react"));
const spinner_hooks_1 = require("./spinner.hooks");
/** The context for the {@link SpinnerContextValue} */
exports.SpinnerContext = react_1.default.createContext({});
/**
 * A component that provides the {@link SpinnerContextValue} to its children
 * and renders the spinner component onto the DOM.
 * @param props.children - the children of the component
 * @returns the spinner context provider
 */
const SpinnerProvider = ({ initialVisible = true, children }) => {
    const { show, hide, spinner } = (0, spinner_hooks_1.useSpinner)({ initialVisible });
    const value = react_1.default.useMemo(() => ({ show, hide }), [show, hide]);
    return (react_1.default.createElement(exports.SpinnerContext.Provider, { value: value },
        children,
        spinner));
};
exports.SpinnerProvider = SpinnerProvider;
/**
 * A hook that provides access to the {@link SpinnerContextValue} when
 * used within a {@link SpinnerProvider}.
 * @returns the spinner context value
 */
const useSpinnerContext = () => {
    const context = react_1.default.useContext(exports.SpinnerContext);
    if (!context) {
        throw new Error('"useSpinnerContext" must be used within a "SpinnerProvider"');
    }
    return context;
};
exports.useSpinnerContext = useSpinnerContext;
