"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSpinner = void 0;
const react_1 = __importDefault(require("react"));
const spinner_1 = require("./spinner");
/**
 * A hook that manages the visibility of a spinner. Allows for the
 * spinner to be shown and hidden programmatically. You must
 * position the returned `spinner` element within the DOM.
 * @param props - the {@link UseSpinnerProps}
 * @param props.initialVisible - Whether the spinner should be visible initially. Defaults to `false`
 * @returns the spinner element and a `show` and `hide` function.
 */
const useSpinner = (props) => {
    var _a, _b;
    const [visible, setVisible] = react_1.default.useState((_a = props === null || props === void 0 ? void 0 : props.initialVisible) !== null && _a !== void 0 ? _a : false);
    const show = () => setVisible(true);
    const hide = () => setVisible(false);
    const spinner = visible && react_1.default.createElement(spinner_1.Spinner, { overlay: (_b = props === null || props === void 0 ? void 0 : props.overlay) !== null && _b !== void 0 ? _b : true });
    return { show, hide, spinner };
};
exports.useSpinner = useSpinner;
