"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UseSpinnerContextDemo = exports.UseSpinnerDemo = void 0;
const react_1 = __importDefault(require("react"));
const button_1 = require("../button/button");
const spinner_context_1 = require("./spinner.context");
const spinner_hooks_1 = require("./spinner.hooks");
/**
 * A hook that manages the visibility of a spinner. Allows for the
 * spinner to be shown and hidden programmatically. You must
 * position the returned `spinner` element within the DOM.
 *
 * The recommended usage of this hook is for components that may require
 * showing a spinner for a short period of time and where the spinner needs
 * to be constrained to a parent container that has `position: relative`.
 *
 * While it is possible to use this hook to render a full screen spinner,
 * it is recommended to use the `useSpinnerContext` hook instead.
 */
const UseSpinnerDemo = ({ initialVisible = false, overlay = true, }) => {
    const { show, hide, spinner } = (0, spinner_hooks_1.useSpinner)({ initialVisible, overlay });
    return (react_1.default.createElement("div", { style: {
            display: 'flex',
            flexFlow: 'column',
            gap: '1rem',
            alignItems: 'center',
        } },
        react_1.default.createElement("div", { style: {
                width: '10rem',
                height: '5rem',
                backgroundColor: 'lightblue',
            } }, spinner),
        react_1.default.createElement("div", { style: { display: 'flex', gap: '1rem' } },
            react_1.default.createElement(button_1.Button, { onClick: show }, "Show"),
            react_1.default.createElement(button_1.Button, { onClick: hide }, "Hide"))));
};
exports.UseSpinnerDemo = UseSpinnerDemo;
/**
 * A hook that manages the visibility of the spinner provided by the `SpinnerProvider`.
 * This spinner will always take up the full screen, and defaults to initially being visible.
 * The recommended usage of this hook is for pages that require a spinner to be shown while
 * data is being fetched.
 */
const UseSpinnerContextDemo = () => {
    const { show, hide } = (0, spinner_context_1.useSpinnerContext)();
    return (react_1.default.createElement("div", { style: { display: 'flex', gap: '1rem' } },
        react_1.default.createElement(button_1.Button, { onClick: show }, "Show"),
        react_1.default.createElement(button_1.Button, { onClick: hide }, "Hide")));
};
exports.UseSpinnerContextDemo = UseSpinnerContextDemo;
