/** @jsxImportSource theme-ui */
import React, { ReactNode } from 'react';
import { TextVariant } from '@waystone/core';
import { HasColor, HasVariant } from '../common/interfaces';
/**
 * Props for rendering the {@link Text} component.
 * @extends HasColor
 * @extends HasVariant
 */
export interface TextProps extends Omit<React.HTMLAttributes<HTMLDivElement>, 'color'>, HasColor, HasVariant<TextVariant> {
    /**
     * The type of element to render onto the DOM.
     * @default 'span'
     */
    as?: React.ElementType;
    /**
     * Should the text component place itself on the same line
     * as the preceeding component (if possible).
     * @default false
     */
    inline?: boolean;
    /**
     * The components to render as children.
     */
    children: ReactNode;
}
/**
 * A component for rendering text onto the DOM with props for setting the text variant, color,
 * HTML element type.
 */
export declare const Text: ({ children, as, inline, variant, color, ...rest }: TextProps) => import("theme-ui/jsx-runtime").JSX.Element;
//# sourceMappingURL=text.d.ts.map