"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Waystone = void 0;
const jsx_runtime_1 = require("theme-ui/jsx-runtime");
/** @jsxImportSource theme-ui */
const react_1 = require("react");
const theme_ui_1 = require("theme-ui");
const core_1 = require("@waystone/core");
const baseTextFont = 'https://fonts.googleapis.com/css2?family=Barlow:wght@200;300;400;500;600;700&family=Fira+Code&display=swap';
const baseIconFont = 'https://fonts.googleapis.com/icon?family=Material+Icons|Material+Icons+Outlined|Material+Icons+Two+Tone|Material+Icons+Round|Material+Icons+Sharp';
const addFonts = (options) => {
    const fonts = {
        text: (options === null || options === void 0 ? void 0 : options.textFont) || baseTextFont,
        icons: (options === null || options === void 0 ? void 0 : options.iconFont) || baseIconFont,
    };
    if (!document.getElementById('fontsPreconnect')) {
        const preconnectLink = document.createElement('link');
        preconnectLink.id = 'fontsPreconnect';
        preconnectLink.rel = 'preconnect';
        preconnectLink.href = 'https://fonts.gstatic.com';
        document.head.appendChild(preconnectLink);
    }
    Object.keys(fonts).forEach((key) => {
        const linkExists = document.getElementById(key);
        if (!linkExists) {
            const link = document.createElement('link');
            link.id = key;
            link.rel = 'stylesheet';
            link.href = fonts[key];
            link.crossOrigin = 'anonymous';
            document.head.appendChild(link);
        }
    });
};
/**
 * Creates the theme provider for Waystone.
 * @param props - the props for configuring the theme provider.
 * @returns the Waystone theme provider
 */
const Waystone = ({ theme, fontOptions, children, }) => {
    const parsedTheme = JSON.parse(JSON.stringify(core_1.WaystoneBaseTheme));
    (0, react_1.useEffect)(() => {
        addFonts(fontOptions);
    }, [fontOptions]);
    if (theme) {
        (0, core_1.mergeObjects)(parsedTheme, theme);
    }
    return (0, jsx_runtime_1.jsx)(theme_ui_1.ThemeProvider, Object.assign({ theme: parsedTheme }, { children: children }));
};
exports.Waystone = Waystone;
